VonMisesFailure

Struct VonMisesFailure 

pub struct VonMisesFailure {
    pub yield_stress: f64,
}
Von Mises yield criterion for isotropic ductile materials.

The material fails when the von Mises stress σ_VM ≥ σ_y.

Fields

yield_stress: f64

Yield stress σ_y (Pa).

Implementations

Source

impl VonMisesFailure

pub fn new(yield_stress: f64) -> Self

Create a new von Mises failure criterion.

pub fn von_mises_stress(stress: &[f64; 6]) -> f64

Compute the von Mises effective stress for a Voigt stress state.

stress order: [sigma_11, sigma_22, sigma_33, sigma_23, sigma_13, sigma_12].