pub struct EmissivityModel {
pub wavelengths_nm: Vec<f64>,
pub emissivity: Vec<f64>,
pub temp_coeff: f64,
pub t_ref: f64,
}Expand description
Wavelength- and temperature-dependent emissivity (Kirchhoff’s law).
For a material in thermal equilibrium the emissivity equals the absorptivity: ε(λ, T) = α(λ, T).
Fields
wavelengths_nm: Vec<f64>Emissivity samples at reference wavelengths (nm).
emissivity: Vec<f64>Spectral emissivity values ε ∈ [0, 1].
temp_coeff: f64Temperature coefficient of emissivity (1/K) — linear model.
t_ref: f64Reference temperature for the tabulated values (K).
Implementations
Sourceimpl EmissivityModel
impl EmissivityModel
Sourcepub fn new(
wavelengths_nm: Vec<f64>,
emissivity: Vec<f64>,
temp_coeff: f64,
t_ref: f64,
) -> Self
pub fn new( wavelengths_nm: Vec<f64>, emissivity: Vec<f64>, temp_coeff: f64, t_ref: f64, ) -> Self
Construct an emissivity model.
Sourcepub fn emissivity_at(&self, lam_nm: f64, temp_k: f64) -> f64
pub fn emissivity_at(&self, lam_nm: f64, temp_k: f64) -> f64
Emissivity at wavelength lam_nm and temperature temp_k via linear
interpolation and linear temperature correction.
Sourcepub fn total_emissivity(&self, temp_k: f64) -> f64
pub fn total_emissivity(&self, temp_k: f64) -> f64
Total hemispherical emissivity integrated over the visible spectrum (380–780 nm) using the trapezoidal rule.