TrainingEffect

Struct TrainingEffect 

pub struct TrainingEffect {
    pub cycles: u32,
    pub residual_strains: Vec<f64>,
    pub plateau_stresses: Vec<f64>,
    pub base_residual: f64,
    pub saturated_residual: f64,
    pub rate_residual: f64,
    pub base_plateau: f64,
    pub plateau_drop_per_decade: f64,
}
Models the evolution of SMA behaviour under cyclic mechanical loading.

Repeated loading-unloading cycles cause:

  • Accumulation of residual (irrecoverable) strain
  • Stabilisation of the transformation plateau stress
  • Reduction in hysteresis width
  • Development of two-way shape memory

Fields

cycles: u32

Number of completed cycles.

residual_strains: Vec<f64>

Accumulated residual strain per cycle (list).

plateau_stresses: Vec<f64>

Transformation stress start per cycle (list).

base_residual: f64

Base (first cycle) residual strain per cycle.

saturated_residual: f64

Saturation residual strain.

rate_residual: f64

Rate constant for residual strain saturation.

base_plateau: f64

Base plateau stress (Pa).

plateau_drop_per_decade: f64

Plateau stress reduction per decade of cycles.

Implementations

Source

impl TrainingEffect

pub fn new() -> Self

Create a new training model with defaults typical for NiTi.

Source

impl TrainingEffect

pub fn add_cycle(&mut self)

Record one additional training cycle and update residual and plateau stress histories.

pub fn current_residual(&self) -> f64

Current residual strain after N cycles.

pub fn current_plateau_stress(&self) -> f64

Current plateau stress after N cycles.