pub fn ula_array_factor(
n: u32,
d: f64,
freq: f64,
c: f64,
theta: f64,
theta_steer: f64,
) -> f64Expand description
Array factor for a uniform linear array (ULA) of n omnidirectional elements
spaced d apart at frequency f for steering angle theta_steer [rad].
Returns the normalised power pattern at angle theta [rad]:
AF = |sin(N*ψ/2) / (N * sin(ψ/2))|²
where ψ = k*d*(cos(θ) - cos(θ_steer)).