pub struct PrimaryCreepModel {
pub a: f64,
pub n: f64,
pub m: f64,
}Expand description
Primary creep using Bailey-Norton time-hardening: ε_p = A * σ^n * t^m.
Fields
a: f64Constant A
n: f64Stress exponent n
m: f64Time exponent m (0 < m < 1 for primary hardening)
Implementations
Sourceimpl PrimaryCreepModel
impl PrimaryCreepModel
Sourcepub fn strain(&self, sigma: f64, t: f64) -> f64
pub fn strain(&self, sigma: f64, t: f64) -> f64
Accumulated primary creep strain at stress sigma and time t.
Sourcepub fn strain_rate(&self, sigma: f64, t: f64) -> f64
pub fn strain_rate(&self, sigma: f64, t: f64) -> f64
Primary creep rate: dε/dt = A * σ^n * m * t^(m-1).
Sourcepub fn transition_time(
&self,
norton: &NortonCreep,
sigma: f64,
temperature: f64,
) -> f64
pub fn transition_time( &self, norton: &NortonCreep, sigma: f64, temperature: f64, ) -> f64
Time at which primary rate equals the steady-state (Norton) rate.
Returns the transition time from primary to secondary creep.