pub struct GrayBodyModel {
pub eps_ref: f64,
pub deps_dt: f64,
pub temp_ref: f64,
}Expand description
Gray body model with temperature-dependent emissivity.
Represents a real surface whose emissivity varies with temperature using
a linear model: ε(T) = ε₀ + dε/dT · (T - T_ref).
Fields
eps_ref: f64Emissivity at reference temperature
deps_dt: f64Rate of change of emissivity with temperature [1/K]
temp_ref: f64Reference temperature [K]
Implementations
Sourceimpl GrayBodyModel
impl GrayBodyModel
Sourcepub fn emissivity(&self, temp_k: f64) -> f64
pub fn emissivity(&self, temp_k: f64) -> f64
Emissivity at temperature temp_k.
Sourcepub fn emissive_power(&self, temp_k: f64) -> f64
pub fn emissive_power(&self, temp_k: f64) -> f64
Emissive power [W/m²] at temperature temp_k.
Sourcepub fn effective_blackbody_temperature(&self, temp_k: f64) -> f64
pub fn effective_blackbody_temperature(&self, temp_k: f64) -> f64
Effective temperature that a blackbody would need to emit the same
total power as this gray body at temp_k.
T_eff = T * ε^0.25