pub struct ParticipatingMedia {
pub kappa: f64,
pub sigma_s: f64,
pub temperature: f64,
}Expand description
Participating media (gas radiation) model.
Models radiative transfer through an absorbing/emitting gas via the mean-beam-length approximation.
Reference: Modest, “Radiative Heat Transfer”, 3rd ed.
Fields
kappa: f64Absorption coefficient κ [1/m].
sigma_s: f64Scattering coefficient σ_s [1/m].
temperature: f64Temperature of the medium [K].
Implementations
Sourceimpl ParticipatingMedia
impl ParticipatingMedia
Sourcepub fn new(kappa: f64, sigma_s: f64, temperature: f64) -> Self
pub fn new(kappa: f64, sigma_s: f64, temperature: f64) -> Self
Create a new participating media model.
Sourcepub fn extinction(&self) -> f64
pub fn extinction(&self) -> f64
Extinction coefficient β = κ + σ_s [1/m].
Sourcepub fn optical_depth(&self, path_length: f64) -> f64
pub fn optical_depth(&self, path_length: f64) -> f64
Optical depth over a path length L: τ = β · L.
Sourcepub fn transmittance(&self, path_length: f64) -> f64
pub fn transmittance(&self, path_length: f64) -> f64
Transmittance through a slab of thickness L: T = exp(-τ).
Sourcepub fn emission_optically_thin(&self, path_length: f64) -> f64
pub fn emission_optically_thin(&self, path_length: f64) -> f64
Emitted radiation from a gas column of thickness L [W/m²].
q_emit = κ · σ · T⁴ · L (optically thin approximation)
Sourcepub fn effective_emissivity(&self, path_length: f64) -> f64
pub fn effective_emissivity(&self, path_length: f64) -> f64
Effective emissivity of a gas layer of thickness L.
ε_eff = 1 - exp(-κ·L) (gray gas approximation)
Sourcepub fn mean_beam_length_sphere(radius: f64) -> f64
pub fn mean_beam_length_sphere(radius: f64) -> f64
Mean-beam length for a sphere of radius R: L_m = 0.65 * 2R.
Sourcepub fn mean_beam_length_cylinder(radius: f64) -> f64
pub fn mean_beam_length_cylinder(radius: f64) -> f64
Mean-beam length for a cylinder (infinite, radius R): L_m = 0.95 * 2R.